summaryrefslogtreecommitdiffstats
path: root/kcachegrind/kcachegrind/treemap.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcachegrind/kcachegrind/treemap.h')
-rw-r--r--kcachegrind/kcachegrind/treemap.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kcachegrind/kcachegrind/treemap.h b/kcachegrind/kcachegrind/treemap.h
index a70f5bd4..356c493b 100644
--- a/kcachegrind/kcachegrind/treemap.h
+++ b/kcachegrind/kcachegrind/treemap.h
@@ -222,7 +222,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
*
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
* items on demand, reimplement tqchildren().
*/
class TreeMapItem: public StoredDrawParams
{
@@ -257,7 +257,7 @@ public:
// force a redraw of this item
void redraw();
// delete all tqchildren
void clear();
// force new child generation & refresh
@@ -350,7 +350,7 @@ public:
* For value() sorting, use <textNo> = -2
*
* For fast sorting, set this to -1 before child insertions and call
* again after inserting all tqchildren.
*/
void setSorting(int textNo, bool ascending = true);
@@ -358,18 +358,18 @@ public:
* Resort according to the already set sorting.
*
* This has to be done if the sorting base changes (e.g. text or values
* change). If this is only true for the tqchildren of this item, you can
* set the recursive parameter to false.
*/
void resort(bool recursive = true);
virtual SplitMode splitMode() const;
virtual int rtti() const;
- // not const as this can create tqchildren on demand
- virtual TreeMapItemList* tqchildren();
+ // not const as this can create children on demand
+ virtual TreeMapItemList* children();
protected:
- TreeMapItemList* _tqchildren;
+ TreeMapItemList* _children;
double _sum, _value;
private:
@@ -444,7 +444,7 @@ public:
/**
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
* has no selected tqchildren or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -460,7 +460,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
* Clear selection of all selected items which are tqchildren of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
*/
@@ -472,7 +472,7 @@ public:
* Range means for a hierarchical widget:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
* range of direct tqchildren between but excluding the child
* leading to i1 and the child leading to i2.
*/
void setRangeSelection(TreeMapItem* i1,
@@ -532,7 +532,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
* If a tqchildren value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
* parent/child size relation can not be mapped to a correct
@@ -644,7 +644,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
* Redraws an item with all tqchildren.
* This takes changed values(), sums(), colors() and text() into account.
*/
void redraw(TreeMapItem*);
@@ -222,7 +222,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
- * items on demand, reimplement tqchildren().
+ * items on demand, reimplement children().
*/
class TreeMapItem: public StoredDrawParams
@@ -257,7 +257,7 @@ public:
// force a redraw of this item
void redraw();
- // delete all tqchildren
+ // delete all children
void clear();
// force new child generation & refresh
@@ -350,7 +350,7 @@ public:
*
* For fast sorting, set this to -1 before child insertions and call
- * again after inserting all tqchildren.
+ * again after inserting all children.
*/
void setSorting(int textNo, bool ascending = true);
@@ -358,18 +358,18 @@ public:
*
* This has to be done if the sorting base changes (e.g. text or values
- * change). If this is only true for the tqchildren of this item, you can
+ * change). If this is only true for the children of this item, you can
* set the recursive parameter to false.
*/
@@ -444,7 +444,7 @@ public:
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
- * has no selected tqchildren or parents stays true.
+ * has no selected children or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -460,7 +460,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
- * Clear selection of all selected items which are tqchildren of
+ * Clear selection of all selected items which are children of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
@@ -472,7 +472,7 @@ public:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
- * range of direct tqchildren between but excluding the child
+ * range of direct children between but excluding the child
* leading to i1 and the child leading to i2.
*/
@@ -532,7 +532,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
- * If a tqchildren value() is almost the parents sum(),
+ * If a children value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
@@ -644,7 +644,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
- * Redraws an item with all tqchildren.
+ * Redraws an item with all children.
* This takes changed values(), sums(), colors() and text() into account.
*/